#' ---
#' title: Verbs PL+FI Bayesian GLMER
#' author: Felix Engelmann
#' ---

#+ setup, include=FALSE
require(knitr)
opts_chunk$set(tidy=TRUE, warning=FALSE, message=FALSE, echo=FALSE)

library(rstanarm)
options(mc.cores = parallel::detectCores())
library(dplyr)
library(tidyr)
library(ggplot2)

#+ include=FALSE
## SUMMARY FUNCTION
## Priors: plausible values of 
## prob range from 0.0001 to 0.9999
## Intercept: t(2) a bit like N(0,2.96^2)
## Slope: t(2) a bit like N(0,2.96^2)
summary_stan_model<-function(mod,nfixefs=3){
  samples_m1 <- as.data.frame(mod)
  nfixefs<-nfixefs+1 ## including intercept
  mns<-rep(NA,nfixefs)
  ci95<-matrix(rep(NA,nfixefs*2),ncol=2)
  for(i in 1:nfixefs){
    condnames<-colnames(samples_m1)[1:nfixefs]
    condnames[1]<-"Intercept"
    mns[i]<-round(mean(samples_m1[,i]),digits=4) 
    ci95[i,]<-round(quantile(probs=c(0.025,0.975),samples_m1[,i]),digits=4)
  }
  ## prob less than 0
  prob_less<-rep(NA,nfixefs)
  for(i in 1:nfixefs){
    prob_less[i]<-round(mean(samples_m1[,i]<0),digits=4)
  }
  res<-as.data.frame(cbind(condnames,mns,ci95,prob_less))
  colnames(res)<-c("comparison","mean","lower","upper","P(b<0)")
  return(res)
}



# Load
load("bayeslmm-FIPL-verbs.Rd")



#' Polish
#' =========================== 
data0 <- read.csv("Polish_dataset-final.csv",header=T)


data1 <- subset(data0, !is.na(normalNAd))

data1 <- mutate(data1, PN=factor(pn, labels = c("1sg", "2sg", "3sg", "1pl", "2pl", "3pl")))
data1 %>% group_by(PN) %>% summarise(Mean = mean(1-normalNAd))

#centering age to 48 months
center_mean <- function(x) {
    x_mean=48
    x - x_mean
}

data1$age <- center_mean(data1$ageM)
# head(data1)
# data1$correctNAd

data1$group.PND <- scale(log(data1$group.PND), scale=FALSE)
data1$token.freq3 <- scale(log(data1$token.freq3+1), scale=FALSE)

dataPLnorm <- data1


#' `normalNAd~ (1 + group.PND + token.freq3 + ageM + group.PND:token.freq3 + group.PND:ageM + token.freq3:ageM|participant) + (1|verb) + group.PND + token.freq3 + ageM + group.PND:token.freq3 + group.PND:ageM + token.freq3:ageM`  
#+ include=FALSE, eval=FALSE
bayesPL_normal <- stan_glmer((normalNAd~ (1 + group.PND + token.freq3 + ageM + group.PND:token.freq3 + group.PND:age + token.freq3:age|participant) + (1|verb) + group.PND + token.freq3 + ageM + group.PND:token.freq3 + group.PND:age + token.freq3:age),
                  family=binomial(),
                  prior_intercept=student_t(df=2),
                  prior=student_t(df=2),
                  prior_covariance=decov(regularization=2),
                  data1,
                  adapt_delta = 0.99,
                  chains=4,
                  iter=2000,
                  cores=4)

#+
summary_stan_model(bayesPL_normal, nfixefs=6)





#  ===========================
#' Finnish
#' =========================== 
data0 <- read.csv("Finnish_dataset-final.csv",header=T)

data1=subset(data0, !is.na(normalNAd))

data1 <- mutate(data1, PN=factor(pn, labels = c("1sg", "2sg", "3sg", "1pl", "2pl")))
data1 %>% group_by(PN) %>% summarise(Mean = mean(1-normalNAd))

#centering ageM to 48 months
center_mean <- function(x) {
    x_mean=48
    x - x_mean
}

data1$ageM <- center_mean(data1$ageM)
# head(data1)

data1$subclass.PND <- scale(log(data1$subclass.PND), scale=FALSE)
data1$token.freq <- scale(log(data1$token.freq+1), scale=FALSE)

dataFInorm <- data1

#' `normalNAd~ (1 +subclass.PND +token.freq +ageM +subclass.PND:token.freq +subclass.PND:ageM +token.freq:ageM|participant) +(1|verb) +subclass.PND +token.freq +ageM +subclass.PND:token.freq +subclass.PND:ageM +token.freq:ageM`  
#+ include=FALSE, eval=FALSE
bayesFI_normal <- stan_glmer((normalNAd~ (1 + subclass.PND +token.freq +ageM +subclass.PND:token.freq +subclass.PND:ageM +token.freq:ageM|participant) +(1|verb) +subclass.PND +token.freq +ageM +subclass.PND:token.freq +subclass.PND:ageM +token.freq:ageM),
                  family=binomial(),
                  prior_intercept=student_t(df=2),
                  prior=student_t(df=2),
                  prior_covariance=decov(regularization=2),
                  data1,
                  chains=4,
                  iter=2000,
                  cores=4)

#+
summary_stan_model(bayesFI_normal, nfixefs=6)









#' Pooling interaction
#' =========================== 

data0 <- read.csv("Polish_dataset-final.csv",header=T)
data1 <- subset(data0, !is.na(normalNAd))
center_mean <- function(x) {
    x_mean=48
    x - x_mean
}
data1$age <- center_mean(data1$ageM)
data1$PND <- scale(log(data1$group.PND), scale=FALSE)
data1$tokenfreq <- scale(log(data1$token.freq3+1), scale=FALSE)
dataPLnorm <- data1 %>% mutate(language="PL")



data0 <- read.csv("Finnish_dataset-final.csv",header=T)
data1=subset(data0, !is.na(normalNAd))
center_mean <- function(x) {
    x_mean=48
    x - x_mean
}
data1$age <- center_mean(data1$ageM)
data1$PND <- scale(log(data1$subclass.PND), sclae=FALSE)
data1$tokenfreq <- scale(log(data1$token.freq+1), sclae=FALSE)
dataFInorm <- data1 %>% mutate(language="FI")


# str(dataPLnorm)
# str(dataFInorm)
dataFIPL <- bind_rows(select(dataPLnorm, normalNAd, participant, verb, tokenfreq, PND, age, language), select(dataFInorm, normalNAd, participant, verb, tokenfreq, PND, age, language))

# str(dataFIPL)
# summary(factor(dataFIPL$language))

#+ include=FALSE, eval=FALSE
require(lme4)
lmboth=glmer(normalNAd~ (1|participant)+(1|verb)+PND+tokenfreq+age+PND:tokenfreq, data=dataFIPL, family=binomial)
#+ 
summary(lmboth)

#+ include=FALSE, eval=FALSE
lmboth2=glmer(normalNAd~ (1|participant)+(1|verb)+PND+tokenfreq+age+PND:age, data=dataFIPL, family=binomial)
#+
summary(lmboth2)

#+ include=FALSE, eval=FALSE
lmboth3=glmer(normalNAd~ (1|participant)+(1|verb)+PND+tokenfreq+age+tokenfreq:age, data=dataFIPL, family=binomial)
#+
summary(lmboth3)


#' ## Bayes

#' `normalNAd~ (1 + PND +tokenfreq +age +PND:tokenfreq +PND:age +tokenfreq:age|participant) +(1|verb) +(1|language) +PND +tokenfreq +age +PND:tokenfreq +PND:age +tokenfreq:age`  
#+ include=FALSE, eval=FALSE
bayesFIPL_normal2 <- stan_glmer((normalNAd~ (1 + PND +tokenfreq +age +PND:tokenfreq +PND:age +tokenfreq:age|participant) +(1|verb) +(1|language) +PND +tokenfreq +age +PND:tokenfreq +PND:age +tokenfreq:age),
                  family=binomial(),
                  prior_intercept=student_t(df=2),
                  prior=student_t(df=2),
                  prior_covariance=decov(regularization=2),
                  dataFIPL,
                  chains=4,
                  iter=2000,
                  adapt_delta = 0.97,
                  cores=4)

#+
summary_stan_model(bayesFIPL_normal2, nfixefs=6)




#+ include=FALSE
# ===========================
# Save
# =========================== 
#+ eval=FALSE
save(bayesPL_normal, bayesFI_normal, bayesFIPL_normal2, lmboth, lmboth2, lmboth3, file="bayeslmm-FIPL-verbs.Rd")
